@@ -654,6 +654,54 @@ create_theme (XmlFields * NewTheme)
 			NewTheme->bg_error =
 				g_strdup (g_basename (NewTheme->bg_error));
 		}
+		
+		/*
+		 * upload the resume image 
+		 */
+		dest = g_build_filename (theme_path,
+					 g_basename (NewTheme->bg_resume),
+					 NULL);
+		if (!copy_file (NewTheme->bg_resume, dest))
+		{
+			g_print (_
+				 ("Error! Unable to use the picture %s.\nAborting\n"),
+				 dest);
+			remove_theme (NewTheme->name);
+			return;
+		}
+		else if (g_path_is_absolute (dest))
+		{
+			NewTheme->bg_resume = g_strdup (dest);
+		}
+		else
+		{
+			NewTheme->bg_resume =
+				g_strdup (g_basename (NewTheme->bg_resume));
+		}
+		
+		/*
+		 * upload the suspend image 
+		 */
+		dest = g_build_filename (theme_path,
+					 g_basename (NewTheme->bg_suspend),
+					 NULL);
+		if (!copy_file (NewTheme->bg_suspend, dest))
+		{
+			g_print (_
+				 ("Error! Unable to use the picture %s.\nAborting\n"),
+				 dest);
+			remove_theme (NewTheme->name);
+			return;
+		}
+		else if (g_path_is_absolute (dest))
+		{
+			NewTheme->bg_suspend = g_strdup (dest);
+		}
+		else
+		{
+			NewTheme->bg_suspend =
+				g_strdup (g_basename (NewTheme->bg_suspend));
+		}
 
 		/*
 		 * upload the font file
