@@ -1177,7 +1177,7 @@ _splashy_child (const gchar * seq)
         gboolean _preview = FALSE;
 
 	int ret;
-	
+
 
         /*
          * handle exit signals
@@ -1199,19 +1199,20 @@ _splashy_child (const gchar * seq)
 
         if (strncmp("preview",seq,7) == 0) {
                 _preview = TRUE;
-	    if (!splashy_init(SPL_CONFIG_FILE, "boot")) {
-		ERROR_PRINT("Problems %s",seq);
+	    if ((ret = splashy_init(SPL_CONFIG_FILE, "boot")) < 0) {
+		ERROR_PRINT("Problems boot. Error %d",ret);
 		return 1;
         }
                 
         } else {
-	    if( !splashy_init(SPL_CONFIG_FILE, seq)) {
-		ERROR_PRINT("Problems %s",seq);
+	    if((ret = splashy_init(SPL_CONFIG_FILE, seq)) < 0) {
+		ERROR_PRINT("Problems %s, Error %d",seq,ret);
 		return 1;
         }
         }
 
 
+
         /*
          * close all open filehandles
          */
