@@ -1693,7 +1693,7 @@ splashy_get_password (char *buf, int len, const char * prompt) {
  *  - Checks it the config is sane
  *  @param const char * file    Path to splashy configfile. If NULL, standard is taken
  *  @param const char * mode    Mode of operation: boot, shutdown, resume, suspend
- *  @return gboolean Succes status of init
+ *  @return int	    Returns <0 for error 0 for succes
  */
 int
 splashy_init (const char * file, const char *mode)
@@ -1705,7 +1705,7 @@ splashy_init (const char * file, const char *mode)
 
         if (!splashy_init_config( (file!=NULL?file:SPL_CONFIG_FILE) )) {
             ERROR_PRINT("libsplashy: No config file found at %s", file);
-            return FALSE;
+            return -1;
         }
 
         _current_mode = -1;
@@ -1718,7 +1718,7 @@ splashy_init (const char * file, const char *mode)
         
         if (_current_mode == -1)  {
             ERROR_PRINT("libsplashy: %s is not a legal mode",mode);
-            return FALSE;
+            return -2;
         }
 
         g_string_assign(xpath,"/splashy/progressbar/direction/");
@@ -1746,7 +1746,7 @@ splashy_init (const char * file, const char *mode)
 	cnf_item = splashy_image_path (xpath->str);
         if (!g_file_test (cnf_item, G_FILE_TEST_IS_REGULAR)) {
             ERROR_PRINT("libsplashy: Could not find error image at %s.",cnf_item);
-            return FALSE;
+            return -3;
         }
 
         g_string_assign(xpath,"/splashy/background/");
@@ -1755,7 +1755,7 @@ splashy_init (const char * file, const char *mode)
 	cnf_item = splashy_image_path (xpath->str);
         if (!g_file_test (cnf_item, G_FILE_TEST_IS_REGULAR)) {
             ERROR_PRINT("libsplashy: Could not find background image at %s.",cnf_item);
-            return FALSE;
+            return -4;
 	}
 
 	_current_background = cnf_item;
